==> nextcloud-app-deck-1%3a1.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/da.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personlig",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nået sin udløbsdato.",
    "The board \"%s\" has been shared with you by %s." : "Brættet \"%s\" er blevet delt med dig af %s.",
    "{user} has shared the board %s with you." : "{user} har delt brættet %s med dig.",
    "Finished" : "Færdiggjort",
    "To review" : "Gennemse",
    "Action needed" : "Handling påkrævet",
    "Later" : "Senere",
    "copy" : "kopiér",
    "Done" : "Færdig",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Create new board" : "Opret ny liste",
    "Cancel" : "Annullér",
    "File already exists" : "Fil findes allerede",
    "Do you want to overwrite it?" : "Vil du overskrive den?",
    "Drop your files to upload" : "Drop dine filer for at uploade",
    "Show archived cards" : "Vis arkiverede kort",
    "Details" : "Detaljer",
    "Sharing" : "Deling",
    "Tags" : "Mærkat",
    "Undo" : "Fortryd",
    "Can edit" : "Can edit",
    "Can share" : "Kan dele",
    "Delete" : "Slet",
    "Add a new stack" : "Tilføj en ny stak",
    "Delete list" : "Slet liste",
    "Add card" : "Tilføj kort",
    "Edit" : "Redigér",
    "Title" : "Titel",
    "Members" : "Medlemmer",
    "Due date" : "Forfaldsdato",
    "Remove due date" : "Fjern forfaldsdato",
    "Description" : "Beskrivelse",
    "Formatting help" : "Hjælp til formatering",
    "Attachments" : "Vedhæftede filer",
    "Comments" : "Kommentarer",
    "Modified" : "Ændret",
    "Created" : "Oprettet",
    "Upload attachment" : "Upload vedhæftning",
    "Save" : "Gem",
    "Reply" : "Besvar",
    "Update" : "Opdatér",
    "(group)" : "(gruppe)",
    "seconds ago" : "sekunder siden",
    "Delete card" : "Slet kort",
    "Move card" : "Flyt kort",
    "Archived boards" : "Arkiverede lister",
    "Shared boards" : "Delte lister",
    "Settings" : "Indstillinger",
    "New board title" : "Ny titel på liste",
    "Share" : "Del",
    "Edit board" : "Rediger liste",
    "An error occurred" : "Der var en fejl",
    "Archive board" : "Arkivér liste",
    "Unarchive board" : "Annuller arkivering af liste",
    "Delete board" : "Slet liste",
    "Board details" : "Liste detaljer"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3a1.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/da.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personlig",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nået sin udløbsdato.",
    "The board \"%s\" has been shared with you by %s." : "Brættet \"%s\" er blevet delt med dig af %s.",
    "{user} has shared the board %s with you." : "{user} har delt brættet %s med dig.",
    "Finished" : "Færdiggjort",
    "To review" : "Gennemse",
    "Action needed" : "Handling påkrævet",
    "Later" : "Senere",
    "copy" : "kopiér",
    "Done" : "Færdig",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Add board" : "Tilføj liste",
    "Cancel" : "Annullér",
    "File already exists" : "Fil findes allerede",
    "Do you want to overwrite it?" : "Vil du overskrive den?",
    "Drop your files to upload" : "Drop dine filer for at uploade",
    "Add list" : "Tilføj liste",
    "Hide archived cards" : "Skjul arkiverede kort",
    "Show archived cards" : "Vis arkiverede kort",
    "Details" : "Detaljer",
    "Sharing" : "Deling",
    "Tags" : "Mærkat",
    "Undo" : "Fortryd",
    "Can edit" : "Can edit",
    "Can share" : "Kan dele",
    "Delete" : "Slet",
    "Delete list" : "Slet liste",
    "Add card" : "Tilføj kort",
    "Edit" : "Redigér",
    "Title" : "Titel",
    "Members" : "Medlemmer",
    "Upload attachment" : "Upload vedhæftning",
    "Due date" : "Forfaldsdato",
    "Remove due date" : "Fjern forfaldsdato",
    "Description" : "Beskrivelse",
    "Formatting help" : "Hjælp til formatering",
    "Attachments" : "Vedhæftede filer",
    "Comments" : "Kommentarer",
    "Select Date" : "Vælg dato",
    "Modified" : "Ændret",
    "Created" : "Oprettet",
    "Save" : "Gem",
    "Reply" : "Besvar",
    "Update" : "Opdatér",
    "(group)" : "(gruppe)",
    "Archive card" : "Arkivér kort",
    "Delete card" : "Slet kort",
    "Move card" : "Flyt kort",
    "seconds ago" : "sekunder siden",
    "Archived boards" : "Arkiverede lister",
    "Shared with you" : "Shared with you",
    "Edit board" : "Rediger liste",
    "Board details" : "Liste detaljer",
    "An error occurred" : "Der var en fejl",
    "Today" : "I dag",
    "Tomorrow" : "I morgen",
    "This week" : "Denne uge"
},
"nplurals=2; plural=(n != 1);");
